"""Snide: a remark.js parser in python"""

__author__ = 'Michael Joseph'
__email__ = 'michaeljoseph@gmail.com'
__url__ = 'https://github.com/michaeljoseph/snide'
__version__ = '0.2.2'

from .models import Deck, Slide  # noqa
